Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| PGL DISTRIBUICAO DE ALIMENTOS LTDA
CNPJ: 87.397.865/0021-65 Inscrição Estadual: 1090357122
Evandro Behr - RS 509 KM 08, 6645, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 106474 Série: 208 Data de Emissão: 05/09/2019 18:57:22
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0987 3978 6500 2165 6520 8000 1064 7410 0933 3530
Protocolo de Autorização: 143191216258771
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
5790 | FRUTI - MACA GALA KG | 0,575 | KG | 4,98 | 2,86
5500 | FRUTI - LARANJA SUCO KG | 2,165 | KG | 2,49 | 5,39
132290 | COGUMELO INTEIRO UNIAGRO SC 80G | 1 | UN | 4,69 | 4,69
691630 | AZEITONA VERDE SCAR UNIAGRO SC 80G | 1 | UN | 3,49 | 3,49
679670 | SEMENTE ISLA MULTI MANJERICAO BASILICAO | 1 | UN | 1,99 | 1,99
598080 | PACOCA ROLHA DACOLONIA ZERO ACUC PT 170G | 1 | UN | 4,2 | 4,20
362480020 | MASSA INTEGRAL ORQUIDEA 500G. PENNE | 1 | UN | 3,69 | 3,69
629890 | MASSA ARROZ INTEGRAL URBANO PARAFUS 500G | 1 | UN | 4,89 | 4,89
10060180 | TEMP CANELA AMAZONAS RAMA SC 100G | 1 | UN | 5,39 | 5,39
10067230 | M TOMATE FUGINI TRAD ZERO SC 340G | 2 | UN | 1,99 | 3,98
10067230 | M TOMATE FUGINI TRAD ZERO SC 340G | 1 | UN | 1,99 | 1,99
370180 | ERVA MATE SANTIAGO CHIMARRAO 1KG | 1 | UN | 11,49 | 11,49
381630 | ERVA MATE REI VERDE NATIVA 1KG | 1 | UN | 10,48 | 10,48
798020 | MILHO FUGINI SC 200G | 1 | UN | 2,39 | 2,39
628600 | CARNE MOIDA BOV ACEM RESF SO ATM 500G | 1 | UN | 12,9 | 12,90
Valor total R$ | 79,82
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:33